package org.example;

import com.fabarta.arcgraph.driver.*;
import com.fabarta.arcgraph.driver.internal.value.EdgeSchemaValue;
import com.fabarta.arcgraph.driver.internal.value.EdgeValue;
import com.fabarta.arcgraph.driver.internal.value.VertexValue;
import org.slf4j.LoggerFactory;

import ch.qos.logback.classic.Logger;
import ch.qos.logback.classic.Level;

import java.util.List;

public class App {
    private static Logger levelSet = (Logger) LoggerFactory.getLogger(Logger.ROOT_LOGGER_NAME);
    private static final Logger logger = (Logger) LoggerFactory.getLogger(Logger.ROOT_LOGGER_NAME);

    public static void main(String[] args) throws Exception {
        String level = "INFO";
        levelSet.setLevel(Level.toLevel(level));
        logger.info("Test start ");

        String serverAddress = "dockersrvip:8182";
        String userName = "arcgraph";
        String password = "arcgraph";
        String testGraph = "demo";

        Driver driver = GraphDatabase.driver(serverAddress, AuthTokens.basic(userName, password));
        Session session = driver.session();
        // 0. Drop test graph
        session.run(String.format("DROP GRAPH IF EXISTS %s", testGraph));
        // 1. Create test graph
        session.run(String.format("CREATE GRAPH IF NOT EXISTS %s (PARTITION_NUM=1)", testGraph));
        session.run(String.format("USE %s", testGraph));

        // 2. Create vertex/edge schema
        String[] createSchemaStatements = new String[]{
            "create vertex person (primary key id int(64), name string)",
            "create edge knows(creationDate string, from person to person) with rankable= false",
        };
        for (String statement : createSchemaStatements) {
            session.run(statement);
        }
        // 3. Create vertex/edge data
        String[] createDataStatements = new String[]{
            "insert (:person{id:1, name:\"name1\"})",
            "insert (:person{id:2, name:\"name2\"})",
            "insert (:person{id:3, name:\"name3\"})",
            "insert (:person{id:1})-[:knows{creationDate:\"2021-01-01 01:02:03\"}]->(:person{id:2})",
            "insert (:person{id:2})-[:knows{creationDate:\"2022-01-01 01:02:03\"}]->(:person{id:3})",
        };
        for (String statement : createDataStatements) {
            session.run(statement);
        }

        Result result = session.run("match (n:person) return n.name as name");
        for (GraphRecord record : result.list()) {
            String nameValue = record.get("name").asString();
            System.out.println("nameValue => " + nameValue);
        }
        Result result2 = session.run("match (n:person) return n");
        for (GraphRecord record : result2.list()) {
            VertexValue vertexValue = record.get("n").asVertex();
            String nameValue = vertexValue.get("name").asString();
            System.out.println("nameValue => " + nameValue);
        }

        Result result3 = session.run("match (:person)-[e:knows]->(:person) return e");
        for (GraphRecord record : result3.list()) {
            EdgeValue edgeValue = record.get("e").asEdge();
            String weight = edgeValue.get("creationDate").asString();
            System.out.println("creationDate => " + weight);
        }

        session.close();
        driver.close();
    }
}
